#!/opt/anaconda1anaconda2anaconda3/bin/python
# EASY-INSTALL-SCRIPT: 'GDAL==2.3.2','gdal_proximity.py'
__requires__ = 'GDAL==2.3.2'
__import__('pkg_resources').run_script('GDAL==2.3.2', 'gdal_proximity.py')
